@@ -6,14 +6,16 @@
 
 /******************************************************************************/
 
-const char gVersion[] = "@(#) NcFTP 3.1.1/957 Dec 23 2001, 02:05 PM";
+const char gVersion[] = "@(#) NcFTP 3.1.3/985 Mar 27 2002, 05:07 AM";
 
 /******************************************************************************/
 
 #ifdef O_S
 const char gOS[] = O_S;
-#elif defined(WIN32) || defined(_WINDOWS)
+#elif (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 const char gOS[] = "Windows";
+#elif defined(__CYGWIN__)
+const char gOS[] = "Cygwin";
 #else
 const char gOS[] = "UNIX";
 #endif
@@ -21,7 +23,7 @@ const char gOS[] = "UNIX";
 /******************************************************************************/
 
 const char gCopyright[] = "@(#) \
-Copyright (c) 1992-2001 by Mike Gleason.\n\
+Copyright (c) 1992-2002 by Mike Gleason.\n\
 All rights reserved.\n\
 ";
 
